summaryrefslogtreecommitdiff
path: root/wcfxsusb.c
diff options
context:
space:
mode:
authorkpfleming <kpfleming@5390a7c7-147a-4af0-8ec9-7488f05a26cb>2007-01-31 14:06:34 +0000
committerkpfleming <kpfleming@5390a7c7-147a-4af0-8ec9-7488f05a26cb>2007-01-31 14:06:34 +0000
commitec54d1fb2b09fc3a4027a58317d190a403b148eb (patch)
treed5c80aa828fc4925aa0a30af277d79eb1c739faf /wcfxsusb.c
parent6bea98a5c2eb5aa88ee5f0578c93ee38fa7b810a (diff)
fix up author email addresses
use the kernel's built-in support for module aliases instead of manually doing it in modprobe.conf or equivalent add wctdm8xxp alias for wctdm24xxp git-svn-id: http://svn.digium.com/svn/zaptel/branches/1.2@2043 5390a7c7-147a-4af0-8ec9-7488f05a26cb
Diffstat (limited to 'wcfxsusb.c')
-rw-r--r--wcfxsusb.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/wcfxsusb.c b/wcfxsusb.c
index 0e783ea..64b2613 100644
--- a/wcfxsusb.c
+++ b/wcfxsusb.c
@@ -1,8 +1,8 @@
/*
* Wildcard S100U USB FXS Interface Zapata Telephony Driver
*
* Written by Mark Spencer <markster@linux-support.net>
* Matthew Fredrickson <creslin@linux-support.net>
*
* Copyright (C) 2001, Linux Support Services, Inc.
*
@@ -1514,7 +1514,7 @@ static void __exit wc_cleanup(void)
usb_deregister(&wc_usb_driver);
}
-MODULE_AUTHOR("Mark Spencer <markster@linux-support.net>");
+MODULE_AUTHOR("Mark Spencer <markster@digium.com>");
MODULE_DESCRIPTION("Wildcard USB FXS Interface driver");
#ifdef MODULE_LICENSE
MODULE_LICENSE("GPL");
@@ -1,8 +1,8 @@
* Wildcard S100U USB FXS Interface Zapata Telephony Driver
*
- * Written by Mark Spencer <markster@linux-support.net>
- * Matthew Fredrickson <creslin@linux-support.net>
+ * Written by Mark Spencer <markster@digium.com>
+ * Matthew Fredrickson <creslin@digium.com>
*
* Copyright (C) 2001, Linux Support Services, Inc.